From 3b53b4161db89e1d7221e14a0f63143e3ad2f37c Mon Sep 17 00:00:00 2001
From: Luca Heltai <luca.heltai@sissa.it>
Date: Sat, 14 Apr 2018 17:54:33 +0200
Subject: [PATCH] Fixed JPs comments.

---
 doc/news/changes/minor/20180414LucaHeltai |  6 +++---
 include/deal.II/grid/tria.h               | 15 ++++++++-------
 2 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/doc/news/changes/minor/20180414LucaHeltai b/doc/news/changes/minor/20180414LucaHeltai
index ef21dc4d88..ad3fcaa85f 100644
--- a/doc/news/changes/minor/20180414LucaHeltai
+++ b/doc/news/changes/minor/20180414LucaHeltai
@@ -1,6 +1,6 @@
-New: Introduced Triangulation::reset_manifold(), as a substituted for Triangulation::set_manifold()
-with a single argument. The set_manifold() method with one argument only was used to reset the manifold
-object. This method is now deprecated, in favour of the new, more esplicative, method. 
+New: Introduced Triangulation::reset_manifold(), as a substitute for Triangulation::set_manifold()
+with only one argument. The set_manifold() method with one argument only was used to reset the manifold
+object. This method is now deprecated, in favor of the new, more explicative, method. 
 An additional Triangulation::reset_all_manifolds() method has been added to remove all manifold 
 objects from the triangulation.
 <br>
diff --git a/include/deal.II/grid/tria.h b/include/deal.II/grid/tria.h
index ab771267cd..c6a0eea3da 100644
--- a/include/deal.II/grid/tria.h
+++ b/include/deal.II/grid/tria.h
@@ -1785,23 +1785,24 @@ public:
   void set_manifold (const types::manifold_id number);
 
   /**
    * Reset those parts of the triangulation with the given manifold_id
    * to use a FlatManifold object. This is the default state of a
    * non-curved triangulation, and undoes assignment of a different
    * Manifold object by the function Triangulation::set_manifold()
    *
    * @ingroup manifold
    *
    * @see
    * @ref GlossManifoldIndicator "Glossary entry on manifold indicators"
    */
-  void reset_manifold (const types::manifold_id number);
+  void reset_manifold (const types::manifold_id manifold_number);
 
   /**
-   * Reset all parts of the trianuglation, regardless of their
+   * Reset all parts of the triangulation, regardless of their
    * manifold_id, to use a FlatManifold object. This undoes assignment
    * of all Manifold objects by the function
-   * Triangulation::set_manifold()
+   * Triangulation::set_manifold().
    *
    * @ingroup manifold
    *
@@ -1785,23 +1785,24 @@ public:
 
   /**
-   * Reset those parts of the triangulation with the given manifold_id
-   * to use a FlatManifold object. This is the default state of a
-   * non-curved triangulation, and undoes assignment of a different
-   * Manifold object by the function Triangulation::set_manifold()
+   * Reset those parts of the triangulation with the given
+   * @p manifold_number to use a FlatManifold object. This is the
+   * default state of a non-curved triangulation, and undoes
+   * assignment of a different Manifold object by the function
+   * Triangulation::set_manifold().
    *
    * @ingroup manifold
-- 
2.39.5